@@ -15,3 +15,10 @@ names(adrop(x[1,1,1,drop=FALSE],drop=1:2,one.d=TRUE))
 dim(adrop(x[1,1,1,drop=FALSE],drop=1:2))
 dimnames(adrop(x[1,1,1,drop=FALSE],drop=1:2))
 names(adrop(x[1,1,1,drop=FALSE],drop=1:2))
+x <- array(1:3, dimnames=list(letters[1:3]))
+x
+options(error=function() NULL)
+adrop(x)
+dim(adrop(x))
+adrop(x, NULL)
+dim(adrop(x, NULL))
